package ru.crystals.pos.api.ext.loyal.dto;

import java.util.ArrayList;
import java.util.List;

/**
 * Эта структура описывает результат выполнения сверки итогов.<br>
 * Сверка итогов - сверка данных по оплатам на кассе и в внешней системе.
 */
public class DailyReportResult {
    /**
     * Список строк, составляющих печатный документ о сверке итогов.
     */
    private List<String> printStrings;
    /**
     * Категория результата выполнения сверки.
     */
    private DailyReportResultCode resultCode;
    /**
     * Сообщение оператору в случае, если произошла ошибка.
     */
    private String message;

    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link DailyReportResult}.
     */
    public DailyReportResult() {
        // NOP
    }

    /**
     * Получает список строк, составляющих печатный документ о сверке итогов.
     * @return список строк или пустой список, если их нет.
     */
    public List<String> getPrintStrings() {
        if(printStrings == null) {
            printStrings = new ArrayList<>();
        }
        return printStrings;
    }

    /**
     * Получает категорию результата выполненной сверки итогов.
     * @return категория результата выполненной сверки итогов.
     */
    public DailyReportResultCode getResultCode() {
        return resultCode;
    }

    /**
     * Устанавливает категорию результата выполненной сверки итогов.
     * @param resultCode категория результата выполненной сверки итогов.
     */
    public void setResultCode(DailyReportResultCode resultCode) {
        this.resultCode = resultCode;
    }

    /**
     * Получает сообщение оператору.
     * @return сообщение оператору.
     */
    public String getMessage() {
        return message;
    }

    /**
     * Устанавливает сообщение оператору.
     * @param message сообщение оператору.
     */
    public void setMessage(String message) {
        this.message = message;
    }

    @Override
    public String toString() {
        return "DailyReportResult{" +
                "printStrings=" + printStrings +
                ", resultCode=" + resultCode +
                ", message='" + message + '\'' +
                '}';
    }
}
