package ru.crystals.pos.api.plugin;

import ru.crystals.pos.api.ext.loyal.dto.AdvertisingActionProviderResult;
import ru.crystals.pos.spi.receipt.Receipt;

/**
 * Плагин-поставщик рекламных акций. Данный тип плагина необходим в случаях, когда внешняя система не занимается расчетом скидок самостоятельно,
 * а желает отдать расчет на откуп кассе. В таком случае внешней системе необходимо передать кассе набор условий и результатов - рекламные акций, которые затем будут
 * примешаны к уже имеющимся на кассе акциям и будут участвовать в расчете лояльности для текущего чека.
 *
 * @since 0.0.59
 */
public interface AdvertisingActionProviderPlugin {

    /**
     * Выполняет поставку рекламных акций из внешней системы, которые должны участвовать в расчетах текущего чека.
     * Вызывается перед каждым расчетом скидок.
     *
     * @param receipt текущий расчитываемый на кассе чек.
     * @return структуру с результатами запроса рекламных акций, которые должны принимать участие в расчете чека. Допустимо возвращать <code>null</code>.
     */
    AdvertisingActionProviderResult getAdvertisingActions(Receipt receipt);
}
