package ru.crystals.pos.api.plugin.card;

/**
 * Сущность, описывающая отклик на запрос выполнения "бонусной" (списания, отмены списания бонусов) операции по карте.
 */
public class BonusOperationResponse {
    /**
     * статус выполнения операции
     */
    private BonusOperationStatus responseStatus;

    /**
     * [заполняется только в случае успеха: {@link #responseStatus} == {@link BonusOperationStatus#OK}]
     * Идентификатор транзакции на стороне процессинга, в рамках которой была проведена операция
     */
    private String txId;

    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link BonusOperationResponse}.
     * @param responseStatus статус выполнения операции.
     * @param txId идентификатор транзакции операции.
     */
    public BonusOperationResponse(BonusOperationStatus responseStatus, String txId) {
        this.responseStatus = responseStatus;
        this.txId = txId;
    }

    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link BonusOperationResponse}.
     */
    public BonusOperationResponse() {
        // default
    }

    /**
     * вернет статус выполнения операции
     *
     * @return {@code null} будет распознаваться как {@link BonusOperationStatus#OK}
     */
    public BonusOperationStatus getResponseStatus() {
        return responseStatus;
    }

    /**
     * Устанавливает статус выполнения операции.
     * @param responseStatus статус выполнения операиции.
     */
    public void setResponseStatus(BonusOperationStatus responseStatus) {
        this.responseStatus = responseStatus;
    }

    /**
     * Вернет идентификатор транзакции на стороне процессинга, в рамках которой была проведена операция
     *
     * @return {@code null}, если операцию выполнить не удалось ({@link #getResponseStatus()} != {@link BonusOperationStatus#OK})
     */
    public String getTxId() {
        return txId;
    }

    /**
     * Устанавливает идентификатор транзакции на стороне процессинга, в рамках которой была проведена операция.
     * @param txId идентификатор транзакции.
     */
    public void setTxId(String txId) {
        this.txId = txId;
    }

    @Override
    public String toString() {
        return "BonusOperationResponse{" +
                "responseStatus=" + responseStatus +
                ", txId='" + txId + '\'' +
                '}';
    }
}
