package ru.crystals.pos.spi.plugin.goods;

import ru.crystals.pos.api.plugin.goods.NewLineItem;

/**
 * Оповещатель кассы о добавлении плагинного товара в чек произвольного возврата.
 * @since 0.0.34
 */
public interface AddForRefundCallback {

    /**
     * Метод оповещения кассы об успешном создании позиции и готовности добавить её в чек.
     * @param newLineItem позиция, которая будет добавлена в чек
     * @throws InvalidLineItemException исключение возникает, если аргумент {@code newLineItem} содержит некорректные данные.<br>
     * <b>Данные не будут сохранены в БД кассы, позиция не будет добавлена в чек</b><br>
     * Локализованное сообщение можно получить методом {@link InvalidLineItemException#getLocalizedMessage()}<br>
     * <pre>Причинами возникновения исключения могут быть:
     *  - некорректно заполненные или пустые требуемые поля;
     *  - другими настройками кассы, блокирующими добавление (например превышение суммы чека).
     * </pre>
     * В данной ситуации рекомендуется отобразить сообщение об ошибке и,<br>если возможно, отменить добавление товара.
     */
    void completed(NewLineItem newLineItem) throws InvalidLineItemException;

    /**
     * Метод, вызываемый в случае, когда позиция не может быть добавлена в чек.<br>
     * Причины могут быть разными:<br>
     * - покупатель отказался;<br>
     * - недоступен процессинг;<br>
     * - недействительный товар;<br>
     * - и т.д.
     * @throws CancelDeniedException возникает, когда у кассира нет привилегии для отмены позиции.<br>
     * Управление остается у плагина.<br>
     * Решается административно, например авторизацией пользователем имеющим данную привилегию.
     */
    void notCompleted() throws CancelDeniedException;
}
