package ru.crystals.pos.spi.receipt;

import ru.crystals.pos.api.card.BalanceType;

import java.math.BigDecimal;

/**
 * Бонусный баланс карты
 *
 */
public interface BonusBalance {

    /**
     * Получить текущий баланс бонусов на счету
     *
     * @return баланс бонусов 
     */
    BigDecimal getBalance();

    /**
     * Получить количество бонусов, что позволено списать с этого баланса в текущем чеке
     *
     * @return {@code null}, если расчет этого "потолка списания" не производился (неизвестно сколько можно списать)
     */
    BigDecimal getSumAllowedToChargeOff();

    /**
     * Получить количество бонусов, что решили списать (или уже списали) с этого баланса в текущем чеке
     *
     * @return {@code null}, если количество бонусов для списания [еще] не ввели
     */
    BigDecimal getSumToChargeOff();

    /**
     * Получить наименование бонусной программы/процессинга для отображения в GUI кассы
     *
     * @return наименование бонусного процессинга
     * @since 0.0.54
     */
    default String getBonusProcessingDisplayName() {
        return null;
    }

    /**
     * Коэффициент перевода бонусокопеек в бонусорубли
     * У внешней системы может быть исчисление бонусов в рублях и копейках, тогда этот коэффициент равен 100, т.к. в 1 руб = 100 копеек.
     * Вместо рублей и копеек могут быть другие названия, которые обозначим, как бонусорубли и бонусокопейки.
     * По умолчанию, этот коэффициент равен 100, но если во внешней системе просто бонусы (например баллы),
     * и кассиру необходимо вводить целое значение этих бонусов, то необходимо установить 1
     * @return коэффициент перевода бонусокопеек в бонусорубли
     * @since 0.0.55
     */
    default BigDecimal getMultiplier() {
        return null;
    }

    /**
     * Курс по которому бонусы (а точнее бонусокопейки) конвертируются в деньги (в копейках)
     * Например, если списываем 4 балла внешней системы, а курс 0.25, то спишется 4 / 0.25 = 16 копеек.
     * Если списали 15 рублей, то в баллах это 150 копеек * 0.25 = 37,5 баллов
     * @return курс для конвертации бонусов в деньги
     * @since 0.0.55
     */
    default BigDecimal getRate() {
        return null;
    }

    /**
     * Тип баланса, если используются не просто бонусы, а фишки/марки, то списание их происходит нелинейно,
     * например 10 фишек - 5 рублей скидки, 20 фишек - 8 рублей скидки и т.п.
     * @return тип баланса
     * @since 0.0.60
     */
    default BalanceType getBalanceType() {
        return BalanceType.BONUSES;
    }
}
